==> v0.23.4.zip: fargo/fargo/fargo/admin.py <==
from django.contrib import admin
from django.contrib.auth import get_user_model
from django.utils.html import format_html
from django.utils.translation import ugettext_lazy as _

from . import models


class UserDocumentAdmin(admin.ModelAdmin):
    list_display = ['user', 'filename', 'thumbnail', 'created', 'origin']
    fields = ['user', 'filename', 'thumbnail', 'created', 'origin']
    readonly_fields = ['created', 'thumbnail']
    search_fields = ['user__first_name', 'user__last_name', 'user__email', 'filename',
                     'origin__label']

    def thumbnail(self, instance):
        data_url = instance.document.thumbnail_data_url
        if data_url:
            return format_html('<img src="{0}"/>', data_url)
        return ''
    thumbnail.short_description = _('thumbnail')


class DocumentAdmin(admin.ModelAdmin):
    fields = ['content_hash', 'thumbnail', 'users']
    list_display = ['content_hash', 'thumbnail', 'users']
    readonly_fields = ['thumbnail', 'users']

    def users(self, instance):
        User = get_user_model()
        qs = User.objects.filter(user_documents__document=instance)
        return u', '.join(unicode(u) for u in qs)

    def thumbnail(self, instance):
        data_url = instance.thumbnail_data_url
        if data_url:
            return format_html('<img src="{0}"/>', data_url)
        return ''
    thumbnail.short_description = _('thumbnail')


class ValidationAdmin(admin.ModelAdmin):
    fields = ['user',
              'content_hash',
              'document_type',
              'start',
              'end',
              'data',
              'creator',
              'created',
              'origin']
    readonly_fields = ['created']
    list_display = ['user', 'display', 'document_type', 'start', 'end', 'creator', 'created',
                    'origin']


class OriginAdmin(admin.ModelAdmin):
    fields = ['label', 'slug']
    list_display = ['label', 'slug']


admin.site.register(models.UserDocument, UserDocumentAdmin)
admin.site.register(models.Document, DocumentAdmin)
admin.site.register(models.Validation, ValidationAdmin)
admin.site.register(models.Origin, OriginAdmin)

==> v0.26.zip: fargo/fargo/fargo/admin.py <==
from django.contrib import admin
from django.contrib.auth import get_user_model
from django.utils.html import format_html
from django.utils.translation import ugettext_lazy as _

from . import models


class UserDocumentAdmin(admin.ModelAdmin):
    list_display = ['user', 'filename', 'thumbnail', 'created', 'origin']
    fields = ['id', 'user', 'filename', 'thumbnail', 'created', 'origin']
    readonly_fields = ['created', 'thumbnail']
    search_fields = ['user__first_name', 'user__last_name', 'user__email', 'filename',
                     'origin__label', 'document__content_hash']

    def thumbnail(self, instance):
        return instance.document.thumbnail_img_tag
    thumbnail.short_description = _('thumbnail')


class DocumentAdmin(admin.ModelAdmin):
    fields = ['content_hash', 'thumbnail', 'users']
    list_display = ['content_hash', 'thumbnail', 'users']
    readonly_fields = ['thumbnail', 'users']
    search_fields = ['content_hash', 'content']

    def users(self, instance):
        User = get_user_model()
        qs = User.objects.filter(user_documents__document=instance)
        return u', '.join(unicode(u) for u in qs)

    def thumbnail(self, instance):
        return instance.thumbnail_img_tag
    thumbnail.short_description = _('thumbnail')


class ValidationAdmin(admin.ModelAdmin):
    fields = ['user',
              'content_hash',
              'document_type',
              'start',
              'end',
              'data',
              'creator',
              'created',
              'origin']
    readonly_fields = ['created']
    list_display = ['user', 'display', 'document_type', 'start', 'end', 'creator', 'created',
                    'origin']


class OriginAdmin(admin.ModelAdmin):
    fields = ['label', 'slug']
    list_display = ['label', 'slug']


admin.site.register(models.UserDocument, UserDocumentAdmin)
admin.site.register(models.Document, DocumentAdmin)
admin.site.register(models.Validation, ValidationAdmin)
admin.site.register(models.Origin, OriginAdmin)
